@@ -36,7 +36,7 @@ CONTAINS
     END DO
       plevs = (/100000., 92500., 85000., 70000.,&
        60000., 50000., 40000., 30000., 25000., 20000.,&
-       15000., 10000., 7000., 5000., 3000., 2000., 1000. /)
+       15000., 10000., 7000., 5000., 3000., 2000., 1000., 500., 100. /)
   
     RETURN
   END SUBROUTINE read_coords
@@ -107,7 +107,7 @@ PROGRAM mip_contribution
   INTEGER, PARAMETER :: ntimes = 2    ! number of time samples to process
   INTEGER, PARAMETER :: lon = 4       ! number of longitude grid cells  
   INTEGER, PARAMETER :: lat = 3       ! number of latitude grid cells
-  INTEGER, PARAMETER :: lev = 17       ! number of standard pressure levels
+  INTEGER, PARAMETER :: lev = 19       ! number of standard pressure levels
   INTEGER, PARAMETER :: n2d = 3       ! number of AMIP Table 2 fields to be
                                       !     output.
   INTEGER, PARAMETER :: n3d = 2       ! number of AMIP Table 1a fields to 
@@ -198,7 +198,7 @@ PROGRAM mip_contribution
   !    files should not be overwritten, and instruct CMOR to error exit on 
   !    encountering errors of any severity.
   
-  error_flag = cmor_setup(inpath='Test',   &
+  error_flag = cmor_setup(inpath='Tables',   &
        netcdf_file_action='replace',                                       &
        set_verbosity=1,                                                    &
        exit_control=1)
@@ -209,70 +209,53 @@ PROGRAM mip_contribution
   !   all CF-netCDF files written as part of this dataset.
 
   print*, 'calling cmor_dataset'
-  error_flag = cmor_dataset(                                   &
-       outpath='Test',         &
-       experiment_id='abrupt 4XCO2',           &
-       institution=                                            &
-       'GICC (Generic International Climate Center, ' //       &
-       ' Geneva, Switzerland)',                                &
-       source='GICCM1  2002(giccm_0_brnchT_itea_2, T63L32)',    &
-       calendar='360_day',                                      &
-       realization=1,                                          &
-       history='Output from archive/giccm_03_std_2xCO2_2256.', &
-       comment='Equilibrium reached after 30-year spin-up ' // &
-       'after which data were output starting with nominal '// &
-       'date of January 2030',                                 &
-       references='Model described by Koder and Tolkien ' //   &
-       '(J. Geophys. Res., 2001, 576-591).  Also ' //          &
-       'see http://www.GICC.su/giccm/doc/index.html '  //      &
-       ' 2XCO2 simulation described in Dorkey et al. '//       &
-       '(Clim. Dyn., 2003, 323-357.)',model_id="GICCM1", &
-       forcing="Nat",contact="Barry Bonds",institute_id="PCMDI",&
-       parent_experiment_rip="N/A",parent_experiment_id="N/A",branch_time=bt)
-  
+  error_flag = cmor_dataset_json("Test/common_user_input.json")
   print*, 'returned from cmor_dataset'
 
+  print*, 'calling cmor_set_cur_dataset_attribute'
+  error_flag = cmor_set_cur_dataset_attribute("language","Fortran",0)
+  print*, 'returned from cmor_set_cur_dataset_attribute'
   !  Define axes for 3-d fields
 
   print*, 'defining 3-d axes'
   
   axis2d_ids2(1) = cmor_axis(  &
-       table='Tables/CMIP5_Lmon',    &
+       table='CMIP6_Lmon.json',    &
        table_entry='latitude',       &
        units='degrees_north',        &  
        length=lat,                   &
        coord_vals=alats,             & 
        cell_bounds=bnds_lat)              
   axis2d_ids2(2) = cmor_axis(  &
-       table='Tables/CMIP5_Lmon',    &
+       table='CMIP6_Lmon.json',    &
        table_entry='longitude',      &
        length=lon,                   &
        units='degrees_east',         &
        coord_vals=alons,             &
        cell_bounds=bnds_lon)              
   axis2d_ids2(3) = cmor_axis(  &
-       table='Tables/CMIP5_Lmon',    &
+       table='CMIP6_Lmon.json',    &
        table_entry='time',           &
        units='days since 1979-1-1',  &
        length=ntimes,                &
        interval='1 month')
   axis3d_ids(3) = cmor_axis(  &
-       table='Tables/CMIP5_Amon',    &
+       table='CMIP6_Amon.json',    &
        table_entry='latitude',       &
        units='degrees_north',        &  
        length=lat,                   &
        coord_vals=alats,             & 
        cell_bounds=bnds_lat)              
   axis3d_ids(2) = cmor_axis(  &
-       table='Tables/CMIP5_Amon',    &
+       table='CMIP6_Amon.json',    &
        table_entry='longitude',      &
        length=lon,                   &
        units='degrees_east',         &
        coord_vals=alons,             &
        cell_bounds=bnds_lon)              
   axis3d_ids(1) = cmor_axis(  &
-       table='Tables/CMIP5_Amon',    &
-       table_entry='plevs',       &
+       table='CMIP6_Amon.json',    &
+       table_entry='plev19',       &
        units='Pa',                   &
        length=lev,                   &
        coord_vals=plevs)
@@ -281,7 +264,7 @@ PROGRAM mip_contribution
   !   cmor_write (below).
 print*, 'before time '
   axis3d_ids(4) = cmor_axis(  &
-       table='Tables/CMIP5_Amon',    &
+       table='CMIP6_Amon.json',    &
        table_entry='time',           &
        units='days since 1979-1-1',  &
        length=ntimes,                &
@@ -303,7 +286,7 @@ print*, 'finished defining 2-d axes'
   
   DO m=1,n3d
      var3d_ids(m) = cmor_variable(    &   
-          table='Tables/CMIP5_Amon',  &
+          table='CMIP6_Amon.json',  &
           table_entry=entry3d(m),     &
 !!$          file_suffix='1979-2001',    &
           units=units3d(m),           &
@@ -320,7 +303,7 @@ print*, 'finished defining 2-d axes'
      if (m.eq.3) then
         print*, 'ok our axes are: ',axis2d_ids2
         var2d_ids(m) = cmor_variable(    &
-             table='Tables/CMIP5_Lmon',  & 
+             table='CMIP6_Lmon.json',  & 
              table_entry=entry2d(m),     & 
 !!$          file_suffix='1979-2001',    &
              units=units2d(m),           & 
@@ -330,7 +313,7 @@ print*, 'finished defining 2-d axes'
              original_name=varin2d(m))  
      else 
         var2d_ids(m) = cmor_variable(    &
-             table='Tables/CMIP5_Amon',  & 
+             table='CMIP6_Amon.json',  & 
              table_entry=entry2d(m),     & 
 !!$          file_suffix='1979-2001',    &
              units=units2d(m),           & 
